"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const chai_1 = require("chai");
const src_1 = require("../../src");
const common_1 = require("../../src/common");
const registry_1 = require("../mock/registry");
describe('ComponentSet', () => {
    const dupeComponent = {
        fullName: 'TestDupe',
        type: registry_1.mockRegistry.types.mixedcontentsinglefile,
    };
    const sourceComponents = [
        new src_1.SourceComponent({
            name: 'TestDupe',
            type: registry_1.mockRegistry.types.mixedcontentsinglefile,
        }),
        // creating a copy to ensure it is deduped
        new src_1.SourceComponent({
            name: 'TestDupe',
            type: registry_1.mockRegistry.types.mixedcontentsinglefile,
        }),
        new src_1.SourceComponent({
            name: 'Test2',
            type: registry_1.mockRegistry.types.decomposedtoplevel,
        }),
    ];
    const set = new common_1.ComponentSet(sourceComponents);
    it('should not include duplicate components', () => {
        chai_1.expect(Array.from(set.values())).to.deep.equal([sourceComponents[0], sourceComponents[2]]);
    });
    it('should return matching SourceComponent', () => {
        chai_1.expect(set.get(dupeComponent)).to.deep.equal(sourceComponents[0]);
    });
    it('should correctly test component membership', () => {
        chai_1.expect(set.has(dupeComponent)).to.be.true;
    });
    it('should add a component', () => {
        const set = new common_1.ComponentSet();
        set.add(dupeComponent);
        chai_1.expect(Array.from(set.values())).to.deep.equal([dupeComponent]);
    });
});
//# sourceMappingURL=componentSet.test.js.map