"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const path_1 = require("path");
const chai_1 = require("chai");
const utils_1 = require("../../src/utils");
const path_2 = require("../../src/utils/path");
describe('Path Utils', () => {
    const root = path_1.join('path', 'to', 'whatever');
    describe('baseName', () => {
        it('Should strip all suffixes of a file path and return just the name', () => {
            const path = path_1.join(root, 'a.ext.xyz');
            chai_1.expect(utils_1.baseName(path)).to.equal('a');
        });
        it('Should handle paths with no suffixes', () => {
            const path = path_1.join(root, 'a');
            chai_1.expect(utils_1.baseName(path)).to.equal('a');
        });
    });
    describe('trimUntil', () => {
        it('should return given path if part is not found', () => {
            chai_1.expect(path_2.trimUntil(root, 'test')).to.equal(root);
        });
        it('should return trimmed path up until and including the given part', () => {
            chai_1.expect(path_2.trimUntil(root, 'to')).to.equal(path_1.join('to', 'whatever'));
        });
    });
});
//# sourceMappingURL=path.js.map